+++
title="Introduction sur les concepts de l'infrastructure V2 de Ğ1"
# date = 2024-10-17
weight = 20
sort_by = "weight"
insert_anchor_links = "right"

# [taxonomies]
# authors = ["Matograine",]
+++

{% note(type="warning", markdown="true") %}
**Document de travail.** Ce document n'a pas été validé et ne doit pas être diffusé en dehors du groupe des forgerons et des développeurs
{% end %}

# Fonctionnement de Ğ1 sur l'infrastructure V2

La monnaie Ğ1 a été lancée en 2017. Pendant plusieurs années, son support a été le logiciel Duniter, qui gérait la blockchain, et plusieurs interfaces clientes. L'évolution de Ğ1 vers une infrastructure "V2" implique des changements et introduit quelques nouveaux comportements. Cette partie vise à les présenter.

## Comptes

Les comptes vont avoir un nouveau format. Dans ce nouveau format:

- on parlera d'*adresse* du compte et non de *clef publique*
- toutes les adresses commenceront par `g1`
- un contrôle est intégré à l'adresse, qui empêche les envois à de mauvaises adresses suite à des fautes de frappe

Par ailleurs, le système de création du compte va changer dans le comportement standard. Les logiciels clients vont générer une *phrase mnémonique* de 12 mots aléatoires (qu'on appelle simplement "mnémonique" ou "phrase de passe"). Cependant, vous n'aurez pas à réécrire cette phrase à chaque connexion car les logiciels la stockeront.

Le logiciel Cesium prévoit de pouvoir utiliser l'ancien système d'authentification, par identifiant + mot de passe.

Il sera possible de créer un compte selon le nouveau mode d'authentification et de *migrer* toutes les données liées à son ancien compte (montant et certifications) vers le nouveau

[En savoir plus](@/wiki/doc-v2/comprendre/compte.md)

## Frais et quotas

Dans sa nouvelle infrastructure, Ğ1 a un système de protection contre des attaques visant à surcharger le blockchain. Cette protection implique :
- des *frais* qui sont appliqués sur chaque action (transaction, certification, etc.). Si le réseau n'est pas surchargé, ces frais sont remboursés.
- des *quotas* qui permettent aux comptes membres d'exécuter des actions dans une certaine limite, même quand le réseau est surchargé.

Ces frais sont de l'ordre de 0.015 DU par transaction.

La plupart du temps, ces frais ne devraient pas s'appliquer.

[En savoir plus](@/wiki/doc-v2/comprendre/frais.md)


## Toile de confiance

La monnaie libre doit être créée par chaque individu. Il faut donc identifier un compte à un individu. Dans la monnaie Ğ1, c'est un dispositif technique de 'toile de confiance' ou 'toile relationnelle' qui tient ce rôle.

[Fonctionnement de la toile de confiance]() -> concept global de la TdC

Voici les éléments qui changent dans la nouvelle infrastructure de Ğ1 :

- Un individu ne pourra pas créer d'identité seul. Il devra être invité par un compte membre, et cette invitation tiendra lieu de première certification.
- Cet individu devra ensuite *confirmer l'invitation*. Il choisira à ce moment le pseudonyme de son compte membre. 
- Les certifications devront être *émises* tous les 5 jours, car elles sont enregistrées immédiatement en blockchain. Précédemment, plusieurs certifications pouvaient être émises simultanément, et elles étaient *enregistrées* avec 5 jours d'intervalle.
- La *règle de distance* est évaluée à intervalles réguliers pour toutes les identités qui ont reçu au moins une certification, et non à chaque inscription d'un nouveau membre.
- L'inscription du membre est *déterministe* et non *probabiliste* : si une identité remplit toutes les conditions, alors elle est inscrite en blockchain immédiatement. Précédemment, il pouvait y avoir 50% de chance d'être inscrit un jour et 50% 5 jours après, par exemple.
- Le renouvellement d'adhésion se fait automatiquement, dès qu'on fait une action en blockchain. Il n'est plus besoin de renouveler son adhésion chaque année.

[En pratique]() -> exemple du flus d'adhésion. Explication des différents appels faits par les clients, en particulier la vérification de la règle de distance et la demande d'adhésion.

## Toile de confiance forgeron

En V1, Duniter permettait à toute personne d'écrire des blocs et d'enregistrer des transactions. Ceci a montré des faiblesses dans la fiabilité du réseau, et aurait pu permettre certaines formes d'attaque. Dans la V2, une *toile de confiance forgeron* se superpose à la toile de confiance initiale. Les *forgerons*, membres de cette toile, peuvent créer des blocs. Ils se certifient entre eux sur des bases de *connaissance technique* et non sur le fait qu'ils se connaissent.

[En savoir plus]()

## Clients

Les logiciels clients servent d'interface pour accéder aux données blockchain. Certains vous servent à consulter l'état de votre compte et à faire des actions. D'autres donnent une vue globale

## Infrastructure

La nouvelle infrastructure prévoit quatre types de serveurs pour gérer les données Blockchain (transactions, certifications, etc.) et les données annexes (historique des transactions, annonces, etc.). 

### Noeud miroir

Les noeuds miroir sont directement accessibles par les logiciels clients, sur une adresse de type `wss://g1.coinduf.eu`. Ils ont pour objectif de mettre à disposition les données blockchain aux clients. Par défaut, ces noeuds mettent à disposition des informations sur *l'état actuel* de la blockchain, mais ils ne conservent que l'historique récent des blocs. Certains noeuds miroir ont un rôle d'*archive* et conservent l'ensemble des données blockchain depuis le démarrage.

Les noeuds miroir sont installés avec le logiciel [Duniter2](https://git.duniter.org/nodes/rust/duniter-v2s). Un [tutoriel](@/wiki/doc-v2/installer/miroir/_index.md) vous indique comment en mettre un en place.

### Noeud forgeron

Les noeuds forgeron ne sont pas directement accessibles par les logiciels clients. Leur rôle est d'enregistrer les données dans la blockchain. Ils communiquent avec les autres noeuds (miroir et forgerons) par un protocole pair-à-pair qui n'est pas destiné aux logiciels clients. Ils ne conservent que l'historique récent de la blockchain à des fins de vérification.

Les noeuds forgerons sont installés avec le logiciel [Duniter2](https://git.duniter.org/nodes/rust/duniter-v2s).

#### Oracle de distance

Certains noeuds forgerons ont un rôle d'*oracle*. A intervalles réguliers, ils calculent le respect de la règle de distance par toutes les identités ayant reçu au moins une certification, et mettent ce résultat à disposition :
- des autres noeuds, pour utiliser cette information et intégrer(ou exclure) des membres dans la toile de confiance
- des logiciels clients, pour faire les demandes d'adhésion en évitant de payer des frais.

Les oracles utilisent le même logiciel que les noeuds Duniter, avec une [configuration spécifique](https://duniter.org/wiki/duniter-v2/distance-oracle/).

### Datapod

Les Datapods servent à stocker des données annexes à la Blockchain. Par exemple, ils peuvent stocker l'avatar d'un compte, des petites annonces, ou des messages. Ils sont synchronisés en pair-à-pair par le protocole *IPFS*.

Au démarrage de la nouvelle infrastructure, les datapods seront renseignés avec les données Cesium+ de DuniterV1, pour que les utilisateurs y retrouvent les profils qu'ils avaient remplis.

Ils sont installés avec le logiciel [ipfs-datapod](https://git.duniter.org/nodes/ipfs-datapod/).

### Indexeur

Les indexeurs servent à rendre plus facile le traitement des données blockchain par les clients : ils enregistrent ces données pour conserver un historique des évènements. Par ailleurs, ils les ordonnent pour faciliter la récupération de données liées (par exemple, récupérer le pseudonyme de l'identité d'un compte en même temps que son historique de transactions). Les indexeurs s'appuient sur un noeud miroir archive pour 'écouter' la blockchain.

Les indexeurs peuvent également ordonner certaines informations hébergées par les datapods pour les lier aux informations Blockchain.

Ils sont installés avec le logiciel [Duniter-squid](https://git.duniter.org/nodes/duniter-squid)

## Gouvernance 

En V1, les règles blockchain pouvaient être modifiées si plus de deux tiers des forgerons installaient une nouvelle version du logiciel Duniter. En V2, un *comité technique* vote les évolutions, et elles s'appliquent à tous les forgerons. 

Au démarrage de la nouvelle infrastructure, ce comité technique est composé des développeurs du coeur. L'intention est de poser des règles formelles pour étendre cette gouvernance à d'autres utilisateurs. Mais ceci devra faire l'objet d'un chantier spécifique.

### Trésorerie

Les frais prélevés sur les transactions ne sont pas détruits, ils vont sur un compte spécifique de trésorerie commune. Les règles de dépense de cette trésorerie n'ont pas encore été fixées. Au lancement de la nouvelle infrastructure, il n'est pas prévu que quiconque puisse débloquer ces fonds. Ceci devra faire l'objet d'un chantier spécifique.